translate.convert.poreplace.poreplace

Package translate :: Package convert :: Module poreplace :: Class poreplace |
[hide private]
[frames] | no frames]

# Class poreplace

source code

Instance Methods | [hide private]
convertstring(self, postr) does the conversion required on the given string (nothing in this case) | source code
convertfile(self, thepofile) goes through a po file and converts each element | source code
convertpo(self, inputfile, outputfile, templatefile) reads in inputfile using po, converts using poreplace, writes to outputfile | source code